@@ -1,5 +1,5 @@
 // SPDX-License-Identifier: GPL-2.0
-/* Copyright (C) 2007-2018  B.A.T.M.A.N. contributors:
+/* Copyright (C) 2007-2019  B.A.T.M.A.N. contributors:
  *
  * Andreas Langer <an.langer@gmx.de>
  *
@@ -1210,7 +1210,7 @@ static void sig_handler(int sig)
 	}
 }
 
-int tcpdump(int argc, char **argv)
+static int tcpdump(struct state *state __maybe_unused, int argc, char **argv)
 {
 	struct timeval tv;
 	struct dump_if *dump_if, *dump_if_tmp;
@@ -1351,3 +1351,6 @@ out:
 	bat_hosts_free();
 	return ret;
 }
+
+COMMAND(SUBCOMMAND, tcpdump, "td", 0, NULL,
+	"<interface>       \ttcpdump layer 2 traffic on the given interface");
